##  Example Identity Providers
The following table lists example IdPs for which we've successfully tested SSO implementation.
Identity Provider | Instructions
---|---
Okta | [Configuring SSO with Okta](https://help.sap.com/docs/leanix/ea/configuring-sso-with-okta?locale=en-US&state=PRODUCTION&version=CLOUD "Instructions for configuring single sign-on \(SSO\) with Okta as an identity provider.")
Microsoft Entra ID | [Configuring SSO with Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/configuring-sso-with-microsoft-entra-id?locale=en-US&state=PRODUCTION&version=CLOUD "Instructions for configuring single sign-on \(SSO\) with Microsoft Entra ID as an identity provider.")
SAP Cloud Identity Services - Identity Authentication Service (IAS) | [Configuring SSO with SAP Cloud Identity Services - Identity Authentication Service (IAS)](https://help.sap.com/docs/leanix/ea/configuring-sso-with-sap-cloud-identity-services-identity-authentication-service-ias?locale=en-US&state=PRODUCTION&version=CLOUD "Configure single sign-on \(SSO\) with SAP Cloud Identity Services - Identity Authentication service \(IAS\) as identity provider to enhance security and simplify user authentication.")
PingOne | [Configuring SSO with PingOne](https://help.sap.com/docs/leanix/ea/configuring-sso-with-pingone?locale=en-US&state=PRODUCTION&version=CLOUD "Instructions for configuring single sign-on \(SSO\) with PingOne as an identity provider.")
OneLogin | [Configuring SSO with OneLogin](https://help.sap.com/docs/leanix/ea/configuring-sso-with-onelogin?locale=en-US&state=PRODUCTION&version=CLOUD "Instructions for configuring single sign-on \(SSO\) with OneLogin as an identity provider.")
Microsoft Active Directory Federation Services (AD FS) | [Configuring SSO with Active Directory Federation Services](https://help.sap.com/docs/leanix/ea/configuring-sso-with-active-directory-federation-services?locale=en-US&state=PRODUCTION&version=CLOUD "Instructions for configuring single sign-on \(SSO\) with Active Directory Federation Services \(AD FS\) as an identity provider.")
Shibboleth IdP | Refer to the [Shibboleth IdP documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwiki.shibboleth.net%2Fconfluence%2Fdisplay%2FSHIB2%2F "https://wiki.shibboleth.net/confluence/display/SHIB2/")
CA Single Sign-On | Refer to the [Broadcom documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fwww.ca.com%2Fde%2Fsecurecenter%2Fca-single-sign-on.aspx "http://www.ca.com/de/securecenter/ca-single-sign-on.aspx")
Google IdP | Refer to the [Google documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fsupport.google.com%2Fa%2Fanswer%2F6087519%3Fhl%3Den "https://support.google.com/a/answer/6087519?hl=en")
LemonLDAP::NG | Refer to the [LemonLDAP::NG documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flemonldap-ng.org%2Fdocumentation%2Flatest%2Fidpsaml.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://lemonldap-ng.org/documentation/latest/idpsaml.html")


